@@ -1,12 +1,13 @@
 corPlot <- function (...) {warning("corPlot is deprecated, use plotscatter instead"); plotscatter(...)}
 plotscatter <-
-	function (vars, res=NULL, index.data=NULL, index.res=NULL, add.lm=TRUE, ...) {
+	function (vars, res=NULL, index.data=NULL, index.res=NULL, add.lm=TRUE, ylab = NULL, ...) {
 		if (class(vars)=="LHS") {
 			if (is.null(index.data)) index.data <- 1:get.ninputs(vars)
 			if (is.null(index.res)) index.res <- 1:get.noutputs(vars)
 			data=get.data(vars)
 			results=get.results(vars)
-			plotscatter(data[,index.data], results[,index.res], add.lm=add.lm, ...)
+			if(is.null(ylab)) ylab = vars$res.names[index.res]
+			plotscatter(data[,index.data], results[,index.res], add.lm=add.lm, ylab = ylab, ...)
 		}
 		else {
 			res <- as.data.frame(res)
@@ -22,7 +23,13 @@ plotscatter <-
 			index.var <- 1
 			index.res <- 1
 			for (i in 1:nl) for (j in 1:nc) {
-				oneplotscatter(res[,index.res],vars[, index.var], c(names(vars)[index.var],names(res)[index.res]), add.lm, ...)
+				this.ylab =names(res)[index.res]
+				if (!is.null(ylab)) {
+					if (length(ylab)==1) this.ylab=ylab
+					else this.ylab=ylab[index.res]
+				}
+				
+				oneplotscatter(res[,index.res],vars[, index.var], c(names(vars)[index.var],this.ylab), add.lm, ...)
 				index.res <- index.res +1
 				if (index.res > dim(res)[2]) {index.res <- 1; index.var <- index.var + 1}
 				if (index.var > dim(vars)[2]) break;
